%{!?upstream_version: %global upstream_version %{version}%{?milestone}}
%global modulename neutron_lbaas
%global servicename neutron-lbaas
%global type LBaaS
%global min_neutron_version 1:8.0.0

Name:           openstack-%{servicename}
Version:        9.2.1
Release:        3%{?dist}
Epoch:          1
Summary:        Openstack Networking %{type} plugin

License:        ASL 2.0
URL:            http://launchpad.net/neutron/
Source0:        https://tarballs.openstack.org/%{servicename}/%{servicename}-%{upstream_version}.tar.gz
Source2:        %{servicename}v2-agent.service
Source3:        %{servicename}-dist.conf

#
# patches_ignore=DROP-IN-RPM
# patches_base=9.2.1
#
Patch0001: 0001-Fix-setup.cfg-whitespace.patch
Patch0002: 0002-Implements-ProcessMonitor-in-the-haproxy-driver.patch
Patch0003: 0003-Auto-reschedule-loadbalancers-from-dead-agents.patch
Patch0004: 0004-Tests-helper-function-_send_requests-should-catch-so.patch
Patch0005: 0005-Plugin-to-run-neutron-lbaas-tests-with-tempest.patch
Patch0006: 0006-Use-Tempest-TimeoutException-from-tempest.lib.patch
Patch0007: 0007-Fix-exception-about-loadbalancer_stats.patch
Patch0008: 0008-Switch-to-use-stable-data_utils.patch
Patch0009: 0009-fixed-health-monitor-setting-during-tempest-test.patch

BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  python-barbicanclient
BuildRequires:  python-neutron >= %{min_neutron_version}
BuildRequires:  python-neutron-lib
BuildRequires:  python-pbr
BuildRequires:  python-pyasn1
BuildRequires:  python-pyasn1-modules
BuildRequires:  python-setuptools
BuildRequires:  systemd-units
BuildRequires:	git
# Test deps
BuildRequires:  python-cryptography

Requires:       python-%{servicename} = %{epoch}:%{version}-%{release}
Requires:       openstack-neutron >= %{min_neutron_version}
Requires:       python-neutron-lib >= 0.4.0

# This is not a hard dependency, but it's required by the default lbaas driver
Requires:       haproxy

%description
This is a %{type} service plugin for Openstack Neutron (Networking) service.


%package -n python-%{servicename}
Summary:        Neutron %{type} Python libraries
Group:          Applications/System

Requires:       python-neutron >= %{min_neutron_version}
Requires:       python-alembic >= 0.8.4
Requires:       python-barbicanclient >= 4.0.0
Requires:       python-eventlet
Requires:       python-keystoneauth1 >= 2.10.0
Requires:       python-netaddr >= 0.7.12
Requires:       python-oslo-config >= 2:3.14.0
Requires:       python-oslo-db >= 4.10.0
Requires:       python-oslo-log >= 1.14.0
Requires:       python-oslo-messaging >= 5.2.0
Requires:       python-oslo-serialization >= 1.10.0
Requires:       python-oslo-service >= 1.10.0
Requires:       python-oslo-reports >= 0.6.0
Requires:       python-oslo-utils >= 3.16.0
Requires:       python-pbr
Requires:       python-pyasn1
Requires:       python-pyasn1-modules
Requires:       python-requests
Requires:       python-six >= 1.9.0
Requires:       python-sqlalchemy >= 1.0.10
Requires:       python-stevedore >= 1.16.0
Requires:       pyOpenSSL


%description -n python-%{servicename}
This is a %{type} service plugin for Openstack Neutron (Networking) service.

This package contains the Neutron %{type} Python library.


%package -n python-%{servicename}-tests
Summary:        Neutron %{type} tests
Group:          Applications/System

Requires:       python-%{servicename} = %{epoch}:%{version}-%{release}


%description -n python-%{servicename}-tests
This is a %{type} service plugin for Openstack Neutron (Networking) service.

This package contains Neutron %{type} test files.


%prep
%autosetup -n %{servicename}-%{upstream_version} -S git

# Let's handle dependencies ourselves
rm -f requirements.txt

# Kill egg-info in order to generate new SOURCES.txt
rm -rf neutron_lbaas.egg-info

%build
export PBR_VERSION=%{version}
export SKIP_PIP_INSTALL=1
%{__python2} setup.py build

# Generate configuration files
PYTHONPATH=. tools/generate_config_file_samples.sh
find etc -name *.sample | while read filename
do
    filedir=$(dirname $filename)
    file=$(basename $filename .sample)
    mv ${filename} ${filedir}/${file}
done

# Loop through values in neutron-lbaas-dist.conf and make sure that the values
# are substituted into the lbaas_agent.ini as comments.
while read name eq value; do
  if [ -n "$name" -a -n "$value" ]; then
    sed -ri "0,/^(#)? *$name *=/{s!\(^(#)? *$name *=\).*!\1 $value!}" etc/lbaas_agent.ini
  fi
done < %{SOURCE3}


%install
export PBR_VERSION=%{version}
export SKIP_PIP_INSTALL=1
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}

# Create fake egg-info for the tempest plugin
egg_path=%{buildroot}%{python2_sitelib}/%{modulename}-*.egg-info
tempest_egg_path=%{buildroot}%{python2_sitelib}/%{modulename}_tests.egg-info
mkdir $tempest_egg_path
grep "tempest\|Tempest" %{modulename}.egg-info/entry_points.txt >$tempest_egg_path/entry_points.txt
cat > $tempest_egg_path/PKG-INFO <<EOF
Metadata-Version: 1.1
Name: %{modulename}_tests
Version: %{upstream_version}
Summary: %{servicename} Tempest Plugin
EOF
# Remove any reference to Tempest plugin in the main package entry point
sed -i "/tempest\|Tempest/d" $egg_path/entry_points.txt

# Move rootwrap files to proper location
install -d -m 755 %{buildroot}%{_datarootdir}/neutron/rootwrap
mv %{buildroot}/usr/etc/neutron/rootwrap.d/*.filters %{buildroot}%{_datarootdir}/neutron/rootwrap

# Move config files to proper location
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron

# The generated config files are not moved automatically by setup.py
mv etc/*.ini etc/*.conf %{buildroot}%{_sysconfdir}/neutron

# Install systemd units
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/%{servicename}v2-agent.service

# Install dist conf
install -p -D -m 640 %{SOURCE3} %{buildroot}%{_datadir}/neutron/%{servicename}-dist.conf

# Create configuration directories that can be populated by users with custom *.conf files
mkdir -p %{buildroot}/%{_sysconfdir}/neutron/conf.d/%{servicename}v2-agent

# Make sure neutron-server loads new configuration file
mkdir -p %{buildroot}/%{_datadir}/neutron/server
ln -s %{_sysconfdir}/neutron/%{modulename}.conf %{buildroot}%{_datadir}/neutron/server/%{modulename}.conf


%post
%systemd_post %{servicename}v2-agent.service


%preun
%systemd_preun %{servicename}v2-agent.service


%postun
%systemd_postun_with_restart %{servicename}v2-agent.service


%files
%license LICENSE
%doc AUTHORS CONTRIBUTING.rst README.rst
%{_bindir}/%{servicename}v2-agent
%{_unitdir}/%{servicename}v2-agent.service
%{_datarootdir}/neutron/rootwrap/lbaas-haproxy.filters
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/lbaas_agent.ini
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/neutron_lbaas.conf
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/services_lbaas.conf
%dir %{_sysconfdir}/neutron/conf.d
%dir %{_sysconfdir}/neutron/conf.d/%{servicename}v2-agent
%attr(-, root, neutron) %{_datadir}/neutron/%{servicename}-dist.conf
%{_datadir}/neutron/server/%{modulename}.conf


%files -n python-%{servicename}
%{python2_sitelib}/%{modulename}
%{python2_sitelib}/%{modulename}-%{version}-py%{python2_version}.egg-info
%exclude %{python2_sitelib}/%{modulename}/tests


%files -n python-%{servicename}-tests
%{python2_sitelib}/%{modulename}/tests
%{python2_sitelib}/%{modulename}_tests.egg-info

%changelog
* Mon Aug 14 2017 Ihar Hrachyshka <ihrachys@redhat.com> 1:9.2.1-3
- Seperate entrypoint for tempest plugin, rhbz#1479895

* Wed Aug 09 2017 Steve Linabery <slinaber@redhat.com> 1:9.2.1-2
- fixed health monitor setting during tempest test,
- Switch to use stable data_utils
- Fix exception about loadbalancer_stats
- Use Tempest TimeoutException from tempest.lib

* Mon Aug 07 2017 Steve Linabery <slinaber@redhat.com> 1:9.2.1-1
- Update to 9.2.1 (rhbz#1479061)

* Tue Jul 04 2017 Arie Bregman <abregman@redhat.com> 1:9.2.0-3
- Plugin to run neutron-lbaas tests with tempest (rhbz#1462509)

* Fri May 19 2017 Jason Joyce <jjoyce@redhat.com> 1:9.2.0-2
- Remove subunit-trace fork
- Explicitly list neutron api extensions for tests
- Don't use Tempest internal methods
- tempest: Switch to local copy of tempset/scenario/manager.py
- Tests helper function _send_requests should catch socket.error (rhbz#1362300)

* Tue Mar 14 2017 Jason Joyce <jjoyce@redhat.com> 1:9.2.0-1
- Update to 9.2.0 (1432220)
- gate_hook: Stop writing local.conf directly
- The lb namespace can not be deleted
- Switch HAProxy health check timeout to seconds

* Mon Feb 06 2017 Nir Magnezi <nmagnezi@redhat.com> 1:9.1.0-4
- Fix for error "no attribute tenant_id" (rhbz#1401798)

* Mon Jan 30 2017 Nir Magnezi <nmagnezi@redhat.com> 1:9.1.0-3
- Auto reschedule loadbalancers from dead agents (rhbz#1415829)
- Implements ProcessMonitor in the haproxy driver (rhbz#1415828)

* Mon Jan 09 2017 Jon Schlueter <jschluet@redhat.com> 1:9.1.0-2
- Pass network MTU into namespace driver (lp#1640265)
- HAProxy - Add host routes to the lbaas namespace (lp#1635355)
- Support xenial in devstack install (lp#1640265)

* Tue Nov 08 2016 Jon Schlueter <jschluet@redhat.com> 1:9.1.0-1
- Update to 9.1.0

* Wed Oct 12 2016 Jon Schlueter <jschluet@redhat.com> 1:9.0.0-2
- Fixed lbaasv2 service plugin alias definition

* Thu Oct 06 2016 Haikel Guemar <hguemar@fedoraproject.org> 1:9.0.0-1
- Update to 9.0.0

* Thu Sep 29 2016 Alan Pevec <alan.pevec@redhat.com> 1:9.0.0-0.3.0rc2
- Update to 9.0.0.0rc2

* Wed Sep 21 2016 Alfredo Moralejo <amoralej@redhat.com> 1:9.0.0-0.2.0rc1
- Update to 9.0.0.0rc1

* Wed Sep 14 2016 Haikel Guemar <hguemar@fedoraproject.org> 1:9.0.0-0.1
- Update to 9.0.0.0b3

